# SUS02: How do you align cloud resources to demand?

## References

- [AWS SUS02](https://docs.aws.amazon.com/wellarchitected/latest/framework/sus-02.html)

## Date

2025-11-27

## Focus Area

Alignment to Demand

## Best Practices

### SUS02-BP01: Scale workload infrastructure dynamically
Auto-scaling.

### SUS02-BP02: Align SLAs with sustainability goals
Sustainability SLAs.

### SUS02-BP03: Stop resources no longer required
Clean up unused resources.

### SUS02-BP04: Optimize geographic placement
Data locality.

### SUS02-BP05: Optimize team member resources
WFH, reduce travel.

## Checklist

- [ ] Auto-scaling configured
- [ ] Unused resources cleaned up
- [ ] Geographic optimization
